# Hawkei

[Hawkei](https://hawkei.io) Python library

Interact easily with our API using our Python library.

## Setup

- [Start by creating an account](https://app.hawkei.io/registration)
- Follow the [Quick Start Guide](https://docs.hawkei.io/docs/quick-start) to get set up
- Use our [Python Library](https://docs.hawkei.io/docs/python) to install and configure Hawkei for your platform.

## Documentation & Usage

Documentation is available at [docs.hawkei.io/docs/python](https://docs.hawkei.io/docs/python)
